#!/bin/bash

# ********************************************
# Install Zabbix Agent
# Author: @stirelshka8
# Support version: Ubuntu 22.04, Ubuntu 20.04
# License: MIT
# ********************************************

# Define color codes for output
RED='\033[0;31m'
BLUE='\033[0;34m'
GREEN='\033[0;32m'
YELLOW='\033[0;33m'
DEFAULT='\033[0m'

ROOT_UID=0
ZABBIX_SERVER_IP="192.168.1.56"
ZABBIX_CONFIG_FILE="/etc/zabbix/zabbix_agentd.conf"

CURRENT_DATE=$(date +"%d-%m-%Y %H:%M:%S")

if [ "$UID" -ne "$ROOT_UID" ]; then
  echo -e "${RED}Please run script as root user.${DEFAULT}"; exit 1
fi

# Function to check the success of a command
check_success() {
  if [ $? -ne 0 ]; then
    echo -e "${RED}Error: $1 failed.${DEFAULT}"
    exit 1
  else
    echo -e "${YELLOW}$1 succeeded.${DEFAULT}"
  fi
}

# Check if Zabbix Agent is already installed
if [ -f "$ZABBIX_CONFIG_FILE" ]; then
  echo -e "${BLUE}Zabbix Agent already installed, resetting config.${DEFAULT}"

  # Update server configuration in Zabbix Agent config file
  sed -i "s/^Server=.*/Server=$ZABBIX_SERVER_IP/g" $ZABBIX_CONFIG_FILE
  check_success "Updating Server in config file"

  sed -i "s/^ServerActive=.*/ServerActive=$ZABBIX_SERVER_IP/g" $ZABBIX_CONFIG_FILE
  check_success "Updating ServerActive in config file"
else
  # Download and install Zabbix repository package
  wget https://repo.zabbix.com/zabbix/7.0/ubuntu/pool/main/z/zabbix-release/zabbix-release_7.0-2+ubuntu22.04_all.deb
  check_success "Downloading Zabbix repository package"

  dpkg -i zabbix-release_7.0-2+ubuntu22.04_all.deb
  check_success "Installing Zabbix repository package"

  # Update package lists and install Zabbix Agent
  apt update
  check_success "Updating package lists"

  apt install zabbix-agent -y
  check_success "Installing Zabbix Agent"

  # Enable and restart Zabbix Agent service
  systemctl enable zabbix-agent
  check_success "Enabling Zabbix Agent service"

  systemctl restart zabbix-agent
  check_success "Restarting Zabbix Agent service"

  # Update server configuration in Zabbix Agent config file
  sed -i "s/^Server=127.0.0.1/Server=$ZABBIX_SERVER_IP/g" $ZABBIX_CONFIG_FILE
  check_success "Updating Server in config file"

  sed -i "s/^ServerActive=127.0.0.1/ServerActive=$ZABBIX_SERVER_IP/g" $ZABBIX_CONFIG_FILE
  check_success "Updating ServerActive in config file"
fi

# Restart Zabbix Agent service to apply changes
systemctl restart zabbix-agent
check_success "Restarting Zabbix Agent service"

echo "Installation finished successfully successfully at: $CURRENT_DATE" >> install-agent.log
echo "Server IP: $ZABBIX_SERVER_IP" >> install-agent.log


echo -e "${GREEN}Zabbix Agent Installed and Configured Successfully${DEFAULT}"
